@@ -3,6 +3,7 @@
 #ifndef _MD5_H
 #define _MD5_H
 
+#include "zncconfig.h"
 #include <string>
 using std::string;
 
@@ -30,7 +31,7 @@ public:
 	CMD5();
 	CMD5(const string& sText);
 	CMD5(const char* szText, uint32 nTextLen);
-	virtual ~CMD5();
+	~CMD5();
 
 	operator string() const
 	{
