@@ -8,7 +8,7 @@ ACLOCAL=${ACLOCAL-aclocal}
 AUTOHEADER=${AUTOHEADER-autoheader}
 AUTOCONF=${AUTOCONF-autoconf}
 AUTOMAKE=${AUTOMAKE-automake}
-ACLOCAL_FLAGS="${ACLOCAL_FLAGS} ${FLAGS}"
+ACLOCAL_FLAGS="${ACLOCAL_FLAGS--I m4} ${FLAGS}"
 AUTOHEADER_FLAGS="${AUTOHEADER_FLAGS} ${FLAGS}"
 AUTOCONF_FLAGS="${AUTOCONF_FLAGS} ${FLAGS}"
 AUTOMAKE_FLAGS="${AUTOMAKE_FLAGS---add-missing} ${FLAGS}"
