@@ -6,9 +6,10 @@
  * by the Free Software Foundation.
  */
 
-#include "User.h"
 #include "Client.h"
+#include "FileUtils.h"
 #include "Server.h"
+#include "User.h"
 
 #include <syslog.h>
 
@@ -162,4 +163,8 @@ private:
 	CString m_sLogFile;
 };
 
+template<> void TModInfo<CAdminLogMod>(CModInfo& Info) {
+	Info.SetWikiPage("adminlog");
+}
+
 GLOBALMODULEDEFS(CAdminLogMod, "Log ZNC events to file and/or syslog.")
