@@ -25,6 +25,10 @@ public:
 		AddCommand("GetFormat", static_cast<CModCommand::ModCmdFunc>(&CIdentFileModule::GetFormat));
 		AddCommand("SetFormat", static_cast<CModCommand::ModCmdFunc>(&CIdentFileModule::SetFormat),
 			"<format>");
+		AddCommand("Show",      static_cast<CModCommand::ModCmdFunc>(&CIdentFileModule::Show));
+
+		m_pISpoofLockFile = NULL;
+		m_pIRCSock = NULL;
 	}
 
 	virtual ~CIdentFileModule() {
@@ -51,6 +55,14 @@ public:
 		PutModule("Format would be expanded to: " + m_pUser->ExpandString(GetNV("Format")));
 	}
 
+	void Show(const CString& sLine) {
+		PutModule("m_pISpoofLockFile = " + CString((long long)m_pISpoofLockFile));
+		PutModule("m_pIRCSock = " + CString((long long)m_pIRCSock));
+		if (m_pIRCSock) {
+			PutModule("user = " + m_pIRCSock->GetUser()->GetUserName());
+		}
+	}
+
 	void OnModCommand(const CString& sCommand) {
 		if (m_pUser->IsAdmin()) {
 			HandleCommand(sCommand);
@@ -98,7 +110,7 @@ public:
 	}
 
 	void ReleaseISpoof() {
-		DEBUG("Releasing ident spoof for user [" + m_pUser->GetUserName() + "]");
+		DEBUG("Releasing ident spoof for user [" + (m_pUser ? m_pUser->GetUserName() : "<no user>") + "]");
 
 		m_pIRCSock = NULL;
 
