@@ -10,6 +10,9 @@
 
 #include "Modules.h"
 
+#if HAVE_VISIBILITY
+#pragma GCC visibility push(default)
+#endif
 class CPerlModule : public CModule {
 	CString m_sPerlID;
 	VWebSubPages* _GetSubPages();
@@ -33,12 +36,9 @@ public:
 	virtual void OnIRCDisconnected();
 	virtual void OnIRCConnected();
 	virtual EModRet OnIRCConnecting(CIRCSock *pIRCSock);
+	virtual void OnIRCConnectionError(CIRCSock *pIRCSock);
 	virtual EModRet OnIRCRegistration(CString& sPass, CString& sNick, CString& sIdent, CString& sRealName);
 	virtual EModRet OnBroadcast(CString& sMessage);
-	virtual EModRet OnConfigLine(const CString& sName, const CString& sValue, CUser* pUser, CChan* pChan);
-	virtual void OnWriteUserConfig(CFile& Config);
-	virtual void OnWriteChanConfig(CFile& Config, CChan& Chan);
-	virtual EModRet OnDCCUserSend(const CNick& RemoteNick, unsigned long uLongIP, unsigned short uPort, const CString& sFile, unsigned long uFileSize);
 	virtual void OnChanPermission(const CNick& OpNick, const CNick& Nick, CChan& Channel, unsigned char uMode, bool bAdded, bool bNoChange);
 	virtual void OnOp(const CNick& OpNick, const CNick& Nick, CChan& Channel, bool bNoChange);
 	virtual void OnDeop(const CNick& OpNick, const CNick& Nick, CChan& Channel, bool bNoChange);
@@ -174,3 +174,6 @@ inline double GetVersion() {
 inline CString GetVersionExtra() {
 	return VERSION_EXTRA;
 }
+#if HAVE_VISIBILITY
+#pragma GCC visibility pop
+#endif
