@@ -16,6 +16,7 @@
 
 #include "Chan.h"
 #include "User.h"
+#include "FileUtils.h"
 #include <sys/stat.h>
 
 #define CRYPT_VERIFICATION_TOKEN "::__:SAVEBUFF:__::"
@@ -68,7 +69,7 @@ public:
 			}
 		}
 		else if( sArgs.empty() )
-			m_sPassword = CBlowfish::MD5( CRYPT_LAME_PASS ); 
+			m_sPassword = CBlowfish::MD5( CRYPT_LAME_PASS );
 		else
 			m_sPassword = CBlowfish::MD5(sArgs);
 
@@ -334,5 +335,9 @@ void CSaveBuffJob::RunJob()
 	p->SaveBufferToDisk();
 }
 
+template<> void TModInfo<CSaveBuff>(CModInfo& Info) {
+	Info.SetWikiPage("savebuff");
+}
+
 MODULEDEFS(CSaveBuff, "Stores channel buffers to disk, encrypted")
 
